@@ -1,7 +1,7 @@
 package Taskwarrior::Kusarigama::Plugin::Renew;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: create a follow-up task upon completion
-$Taskwarrior::Kusarigama::Plugin::Renew::VERSION = '0.9.2';
+$Taskwarrior::Kusarigama::Plugin::Renew::VERSION = '0.9.3';
 
 use 5.10.0;
 use strict;
@@ -68,13 +68,13 @@ sub on_exit {
 sub on_add {
     my( $self, $task ) = @_;
 
-    my $due = $task->{rdue};
-
     for my $field ( qw/ due wait scheduled / ) {
         next if $task->{$field};
 
         my $value = $task->{ 'r' . $field } or next;
 
+        my $due = $task->{due};
+
         $value =~ s/due/$due/g;
 
         $task->{$field} = $self->r_calc($value);
@@ -95,7 +95,7 @@ Taskwarrior::Kusarigama::Plugin::Renew - create a follow-up task upon completion
 
 =head1 VERSION
 
-version 0.9.2
+version 0.9.3
 
 =head1 SYNOPSIS
 
